@@ -17,8 +17,8 @@
  */
 
 
-#ifndef _BMC_CONFIG_LAN_CONF_AUTH_SECTION_H_
-#define _BMC_CONFIG_LAN_CONF_AUTH_SECTION_H_
+#ifndef BMC_CONFIG_LAN_CONF_AUTH_SECTION_H
+#define BMC_CONFIG_LAN_CONF_AUTH_SECTION_H
 
 #include "bmc-config.h"
 #include "bmc-config-sections.h"
@@ -27,4 +27,4 @@ struct config_section * bmc_config_lan_conf_auth_section_get (bmc_config_state_d
 							      unsigned int config_flags,
 							      int channel_index);
 
-#endif /* _BMC_CONFIG_LAN_CONF_AUTH_SECTION_H_ */
+#endif /* BMC_CONFIG_LAN_CONF_AUTH_SECTION_H */
