@@ -16,9 +16,9 @@
  * 
  */
 
-#ifndef _IPMI_PET_ARGP_H
-#define _IPMI_PET_ARGP_H
+#ifndef IPMI_PET_ARGP_H
+#define IPMI_PET_ARGP_H
 
 void ipmi_pet_argp_parse (int argc, char **argv, struct ipmi_pet_arguments *cmd_args);
 
-#endif
+#endif /* IPMI_PET_ARGP_H */
