@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_SUNBMC_DRIVER_H
-#define _IPMI_SUNBMC_DRIVER_H 1
+#ifndef IPMI_SUNBMC_DRIVER_H
+#define IPMI_SUNBMC_DRIVER_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -71,5 +71,4 @@ int ipmi_sunbmc_cmd (ipmi_sunbmc_ctx_t ctx,
 }
 #endif
 
-#endif /* ipmi-sunbmc-driver.h */
-
+#endif /* IPMI_SUNBMC_DRIVER_H */
