@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_SOL_PAYLOAD_H
-#define _IPMI_SOL_PAYLOAD_H
+#ifndef IPMI_SOL_PAYLOAD_H
+#define IPMI_SOL_PAYLOAD_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -132,4 +132,4 @@ int fill_sol_payload_data_remote_console_to_bmc (uint8_t packet_sequence_number,
 }
 #endif
 
-#endif
+#endif /* IPMI_SOL_PAYLOAD_H */
