@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_DEVICE_TYPES_OEM_SPEC_H
-#define _IPMI_DEVICE_TYPES_OEM_SPEC_H
+#ifndef IPMI_DEVICE_TYPES_OEM_SPEC_H
+#define IPMI_DEVICE_TYPES_OEM_SPEC_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -27,4 +27,4 @@ extern "C" {
 }
 #endif
 
-#endif
+#endif /* IPMI_DEVICE_TYPES_OEM_SPEC_H */
