@@ -48,6 +48,17 @@ extern "C" {
 
 #define IPMI_EVENT_READING_TYPE_CODE_OEM_DELL_FAILURE                   0x8A
 
+/*******************************************
+ * HP                                      *
+ *******************************************/
+
+/*
+ * HP Proliant DL160 G8
+ */
+
+#define IPMI_EVENT_READING_TYPE_CODE_OEM_HP_UID_LIGHT                  0x70
+#define IPMI_EVENT_READING_TYPE_CODE_OEM_HP_HEALTH_LED                 0x71
+
 /*******************************************
  * Intel                                   *
  *******************************************/
@@ -151,6 +162,7 @@ extern "C" {
  * Supermicro X9DRi-F (X9DRI_F)
  * Supermicro X9DRI-LN4F+ (X9DRI_LN4F_PLUS)
  * Supermicro X9SPU-F-O (X9SPU_F_O)
+ * Supermicro X9SCM-iiF (X9SCM_IIF)
  */
 
 /* achu: not official names, named based on use context */
