@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_FIRMWARE_FIRMWARE_COMMAND_DISCOVERY_CMDS_TEMPLATES_H
-#define _IPMI_FIRMWARE_FIRMWARE_COMMAND_DISCOVERY_CMDS_TEMPLATES_H
+#ifndef IPMI_FIRMWARE_FIRMWARE_COMMAND_DISCOVERY_CMDS_TEMPLATES_H
+#define IPMI_FIRMWARE_FIRMWARE_COMMAND_DISCOVERY_CMDS_TEMPLATES_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -358,4 +358,4 @@ FIID Template: tmpl_cmd_get_oem_netfn_iana_support_rs
 }
 #endif
 
-#endif  /* _IPMI_EVENT_CMDS_TEMPLATES_H */
+#endif /* IPMI_EVENT_CMDS_TEMPLATES_H */
