@@ -42,12 +42,17 @@ sensor_read_set_sensor_read_errnum_by_errno (ipmi_sensor_read_ctx_t ctx, int __e
 {
   assert (ctx && ctx->magic == IPMI_SENSOR_READ_CTX_MAGIC);
 
-  if (__errno == 0)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_SUCCESS;
-  else if (__errno == ENOMEM)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_OUT_OF_MEMORY;
-  else
-    ctx->errnum = IPMI_SENSOR_READ_ERR_INTERNAL_ERROR;
+  switch (__errno)
+    {
+    case 0:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_SUCCESS;
+      break;
+    case ENOMEM:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_OUT_OF_MEMORY;
+      break;
+    default:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_INTERNAL_ERROR;
+    }
 }
 
 void
@@ -55,19 +60,25 @@ sensor_read_set_sensor_read_errnum_by_fiid_object (ipmi_sensor_read_ctx_t ctx, f
 {
   assert (ctx && ctx->magic == IPMI_SENSOR_READ_CTX_MAGIC);
 
-  if (fiid_obj_errnum (obj) == FIID_ERR_SUCCESS)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_SUCCESS;
-  else if (fiid_obj_errnum (obj) == FIID_ERR_OUT_OF_MEMORY)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_OUT_OF_MEMORY;
-  else if (fiid_obj_errnum (obj) == FIID_ERR_DATA_NOT_AVAILABLE)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_IPMI_ERROR;
-  else if (fiid_obj_errnum (obj) == FIID_ERR_FIELD_NOT_FOUND
-           || fiid_obj_errnum (obj) == FIID_ERR_DATA_NOT_BYTE_ALIGNED
-           || fiid_obj_errnum (obj) == FIID_ERR_REQUIRED_FIELD_MISSING
-           || fiid_obj_errnum (obj) == FIID_ERR_FIXED_LENGTH_FIELD_INVALID
-           || fiid_obj_errnum (obj) == FIID_ERR_DATA_NOT_AVAILABLE
-           || fiid_obj_errnum (obj) == FIID_ERR_NOT_IDENTICAL)
-    ctx->errnum = IPMI_SENSOR_READ_ERR_PARAMETERS;
-  else
-    ctx->errnum = IPMI_SENSOR_READ_ERR_INTERNAL_ERROR;
+  switch (fiid_obj_errnum (obj))
+    {
+    case FIID_ERR_SUCCESS:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_SUCCESS;
+      break;
+    case FIID_ERR_OUT_OF_MEMORY:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_OUT_OF_MEMORY;
+      break;
+    case FIID_ERR_DATA_NOT_AVAILABLE:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_SYSTEM_ERROR;
+      break;
+    case FIID_ERR_FIELD_NOT_FOUND:
+    case FIID_ERR_DATA_NOT_BYTE_ALIGNED:
+    case FIID_ERR_REQUIRED_FIELD_MISSING:
+    case FIID_ERR_FIXED_LENGTH_FIELD_INVALID:
+    case FIID_ERR_NOT_IDENTICAL:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_PARAMETERS;
+      break;
+    default:
+      ctx->errnum = IPMI_SENSOR_READ_ERR_INTERNAL_ERROR;
+    }
 }
